Exception: Tenax::ConfigurationError
- Defined in:
- lib/tenax/errors.rb
Overview
Raised when the gem is configured incorrectly. Always raised synchronously from inside Tenax.configure, with a message that identifies the offending profile and option.
Raised when the gem is configured incorrectly. Always raised synchronously from inside Tenax.configure, with a message that identifies the offending profile and option.