Exception: Tenax::RetryLimitExceeded
- Inherits:
-
ExecutionError
- Object
- StandardError
- Error
- ExecutionError
- Tenax::RetryLimitExceeded
- Defined in:
- lib/tenax/errors.rb
Overview
Raised when an operation has exhausted its retry budget. The underlying error from the final attempt is preserved as #cause.
Instance Attribute Summary
Attributes inherited from ExecutionError
Instance Method Summary collapse
-
#initialize(profile_name:, attempts:) ⇒ RetryLimitExceeded
constructor
A new instance of RetryLimitExceeded.
Constructor Details
#initialize(profile_name:, attempts:) ⇒ RetryLimitExceeded
Returns a new instance of RetryLimitExceeded.
77 78 79 80 81 82 83 |
# File 'lib/tenax/errors.rb', line 77 def initialize(profile_name:, attempts:) super( "retry limit exceeded for profile #{profile_name.inspect} after #{attempts} attempt(s)", profile_name: profile_name, attempts: attempts ) end |